==> fetch.php?media=download_software:mae3xx:mae3xx_rootfs_bionic_v4_2_1.tar.xz: opt/mae3xx/app/AppServer/Handlers/NTP.py <==
# -*- coding: utf-8 -*-
from Handlers import BaseHandler
import os
#-------------------------------------------------------------------------------
#
#-------------------------------------------------------------------------------
class NTP(BaseHandler.BaseHandler):
    #=======================================================
    # 
    #=======================================================
    def __init__(self):
        self.ntp_conf = '/etc/ntp.conf'
        self.name = 'NTP'
        self.cron = '/etc/cron.daily/ntpdate'
        self.ntpdate_conf = '/etc/default/ntpdate'
        self.crontab = '/etc/crontab'
        self.daily_ntpdate = "%s %s   * * *   root    /usr/sbin/ntpdate-debian -s #MA-E300 AppServer write."

    #=======================================================
    # 
    #=======================================================
    def Get(self, request):
            
        status = 200
        return self.readConfig(), status

    #=======================================================
    # 
    #=======================================================
    def Put(self, request):

        status = 200
        self.writeConfig(request.json)
        self.write_crontab(request.json)
        self.restart(request.json)
        #self.set_crondaily(request.json)
        
        return status

    #=======================================================
    # 
    #=======================================================
    def readConfig(self):

        ntp_server = {'printp':'', 'secntp':'', 'ntpClient':'no', 'periodic':'no', 'time':'', 'ntpq':''}
        status = self.call(['service','ntp','status'])
        if status == 0:
            ntp_server['ntpClient'] = 'yes'
            ntp_server['ntpq'] = self.exec_ntpq()

        else:
            ntpdate = self.read_crontab()
            if ntpdate['use']:
                ntp_server['periodic'] = 'yes'
                ntp_server['time'] = ntpdate['time']
    
        config = open(self.ntp_conf, "r")
        for line in config:
            if line.startswith('#') == True:
                pass
            if line.startswith('server '):
                if ntp_server['printp'] == '':
                    ntp_server['printp'] = line.split()[1]
                elif ntp_server['secntp'] == '':
                    ntp_server['secntp'] = line.split()[1]

        return ntp_server
    #=======================================================
    # 
    #=======================================================
    def writeConfig(self, args):
        
        fd = open(self.ntp_conf, "r")
        read_lines = fd.read()
        fd.close()
        write_lines = []
        flg = False

        for line in read_lines.split('\n'):
            if line.startswith('server '):
                if not flg:
                    if 'printp' in args and args['printp']:
                    #if args['printp']:
                        write_lines.append('server %s' %  args['printp']) 
                    if 'secntp' in args and args['secntp']:
                    #if args['secntp']:
                        write_lines.append('server %s' % args['secntp']) 
                    flg = True
            else:
                write_lines.append(line)
        if not flg:
            if 'printp' in args and args['printp']:
                write_lines.append('server %s' %  args['printp']) 
            if 'secntp' in args and args['secntp']:
                write_lines.append('server %s' % args['secntp']) 
            write_lines.append('\n') 

        fd = open(self.ntp_conf, "w")
        fd.write('\n'.join(write_lines))
        fd.close()

        if args['periodic'] == 'yes':
            fd = open(self.ntpdate_conf, 'r')
            read_lines = fd.read()
            fd.close()
            
            write_lines = []

            for line in read_lines.split('\n'):
                
                if line.startswith('#'):
                    write_lines.append(line)
                if 'NTPDATE_USE_NTP_CONF' in line:
                    write_lines.append('NTPDATE_USE_NTP_CONF=yes')
                elif 'NTPSERVERS' in line:
                    write_lines.append('NTPSERVERS=')
                else:
                    write_lines.append(line)

            fd = open(self.ntpdate_conf, 'w')
            fd.write('\n'.join(write_lines))
            fd.close()

    #=======================================================
    # 
    #=======================================================
    def restart(self, args):

        if args['ntpClient']=='yes':
            action = 'restart'
            startup = 'enable'
        else:
            action = 'stop'
            startup = 'disable'

        self.service('ntp', action)
        self.service('ntp', startup)

    #=======================================================
    # 
    #=======================================================
    def exec_ntpq(self):

        output = ''
        result  = self.check_output(['ntpq','-p'])

        if result:
            edit = []
            lines = result.split('\n')
            for line in lines:
                if line.find("==============================") >= 0:
                    edit.append(line[6:])
                else:
                    edit.append(line)
            output = '\n'.join(edit)
        return output

    #=======================================================
    # 
    #=======================================================
    def set_crondaily(self, args):
        
        if args['ntpClient']=='ntpdate':
            fd = open(self.cron, 'w')
            fd.write("#!/bin/sh\n/usr/sbin/ntpdate-debian >/dev/null\n")
            fd.close()
            os.chmod(self.cron, 493)
        else:
            if os.path.exists(self.cron):
                os.remove(self.firmup_file)
    #=======================================================
    # 
    #=======================================================
    def read_crontab(self):
        
        result = {'time':'', 'use':False}
        fd  = open(self.crontab, 'r')
        for line in fd:
            if 'ntpdate-debian' in line:
                sline = line.split(' ')
                result['time'] = '%02d00' % int(sline[1])

                result['use'] = True
                break

        return result

    #=======================================================
    # 
    #=======================================================
    def write_crontab(self, args):
        
        fd  = open(self.crontab, 'r')
        read_lines = fd.read()
        fd.close()
        
        write_lines = []

        for line in read_lines.split('\n'):
            if line:
                if 'ntpdate-debian' in line:
                    pass
                else:
                    write_lines.append(line)

        if args['periodic'] == 'yes':
            write_lines.append(self.daily_ntpdate % (0, int(args['time'][:2])))
        write_lines.append('\n')
        fd = open(self.crontab, 'w')
        fd.write('\n'.join(write_lines))

==> fetch.php?media=download_software:mae3xx:mae3xx_rootfs_bionic_v4_5_0rc5.tar.xz: opt/mae3xx/app/AppServer/Handlers/NTP.py <==
# -*- coding: utf-8 -*-
from Handlers import BaseHandler
import os
# -------------------------------------------------------------------------------
#
# -------------------------------------------------------------------------------


class NTP(BaseHandler.BaseHandler):
    # =======================================================
    #
    # =======================================================
    def __init__(self):
        self.ntp_conf = '/etc/ntp.conf'
        self.name = 'NTP'
        self.cron = '/etc/cron.daily/ntpdate'
        self.ntpdate_conf = '/etc/default/ntpdate'
        self.crontab = '/etc/crontab'
        self.daily_ntpdate = "%s %s   * * *   root    /usr/sbin/ntpdate-debian -s #MA-E300 AppServer write."

    # =======================================================
    #
    # =======================================================
    def Get(self, request):

        status = 200
        return self.readConfig(), status

    # =======================================================
    #
    # =======================================================
    def Put(self, request):

        status = 200
        self.writeConfig(request.json)
        self.write_crontab(request.json)
        self.restart(request.json)
        # self.set_crondaily(request.json)

        return status

    # =======================================================
    #
    # =======================================================
    def readConfig(self):

        ntp_server = {'printp': '', 'secntp': '', 'ntpClient': 'no',
                      'periodic': 'no', 'time': '', 'ntpq': ''}
        status = self.call(['service', 'ntp', 'status'])
        if status == 0:
            ntp_server['ntpClient'] = 'yes'
            ntp_server['ntpq'] = self.exec_ntpq()

        else:
            ntpdate = self.read_crontab()
            if ntpdate['use']:
                ntp_server['periodic'] = 'yes'
                ntp_server['time'] = ntpdate['time']

        config = open(self.ntp_conf, "r")
        for line in config:
            if line.startswith('#') == True:
                pass
            if line.startswith('server '):
                if ntp_server['printp'] == '':
                    ntp_server['printp'] = line.split()[1]
                elif ntp_server['secntp'] == '':
                    ntp_server['secntp'] = line.split()[1]

        return ntp_server
    # =======================================================
    #
    # =======================================================
    def writeConfig(self, args):

        fd = open(self.ntp_conf, "r")
        read_lines = fd.read()
        fd.close()
        write_lines = []
        flg = False

        for line in read_lines.split('\n'):
            if line.startswith('server '):
                if not flg:
                    if 'printp' in args and args['printp']:
                        # if args['printp']:
                        write_lines.append('server %s' % args['printp'])
                    if 'secntp' in args and args['secntp']:
                        # if args['secntp']:
                        write_lines.append('server %s' % args['secntp'])
                    flg = True
            else:
                write_lines.append(line)
        if not flg:
            if 'printp' in args and args['printp']:
                write_lines.append('server %s' % args['printp'])
            if 'secntp' in args and args['secntp']:
                write_lines.append('server %s' % args['secntp'])
            write_lines.append('\n')

        fd = open(self.ntp_conf, "w")
        fd.write('\n'.join(write_lines))
        fd.close()

        if args['periodic'] == 'yes':
            fd = open(self.ntpdate_conf, 'r')
            read_lines = fd.read()
            fd.close()

            write_lines = []

            for line in read_lines.split('\n'):

                if line.startswith('#'):
                    write_lines.append(line)
                if 'NTPDATE_USE_NTP_CONF' in line:
                    write_lines.append('NTPDATE_USE_NTP_CONF=yes')
                elif 'NTPSERVERS' in line:
                    write_lines.append('NTPSERVERS=')
                else:
                    write_lines.append(line)

            fd = open(self.ntpdate_conf, 'w')
            fd.write('\n'.join(write_lines))
            fd.close()

    # =======================================================
    #
    # =======================================================
    def restart(self, args):

        if args['ntpClient'] == 'yes':
            action = 'restart'
            startup = 'enable'
        else:
            action = 'stop'
            startup = 'disable'

        self.service('ntp', action)
        self.service('ntp', startup)

    # =======================================================
    #
    # =======================================================
    def exec_ntpq(self):

        output = ''
        result = self.check_output(['ntpq', '-p'])

        if result:
            edit = []
            lines = result.split('\n')
            for line in lines:
                if line.find("==============================") >= 0:
                    edit.append(line[6:])
                else:
                    edit.append(line)
            output = '\n'.join(edit)
        return output

    # =======================================================
    #
    # =======================================================
    def set_crondaily(self, args):

        if args['ntpClient'] == 'ntpdate':
            fd = open(self.cron, 'w')
            fd.write("#!/bin/sh\n/usr/sbin/ntpdate-debian >/dev/null\n")
            fd.close()
            os.chmod(self.cron, 493)
        else:
            if os.path.exists(self.cron):
                os.remove(self.firmup_file)
    # =======================================================
    #
    # =======================================================
    def read_crontab(self):

        result = {'time': '', 'use': False}
        fd = open(self.crontab, 'r')
        for line in fd:
            if 'ntpdate-debian' in line:
                sline = line.split(' ')
                result['time'] = '%02d00' % int(sline[1])

                result['use'] = True
                break

        return result

    # =======================================================
    #
    # =======================================================
    def write_crontab(self, args):

        fd = open(self.crontab, 'r')
        read_lines = fd.read()
        fd.close()

        write_lines = []

        for line in read_lines.split('\n'):
            if line:
                if 'ntpdate-debian' in line:
                    pass
                else:
                    write_lines.append(line)

        if args['periodic'] == 'yes':
            write_lines.append(self.daily_ntpdate % (0, int(args['time'][:2])))
        write_lines.append('\n')
        fd = open(self.crontab, 'w')
        fd.write('\n'.join(write_lines))
